@@ -1,4 +1,4 @@
-# Copyright (c) 2019 - 2021, Ilan Schnell; All Rights Reserved
+# Copyright (c) 2019 - 2022, Ilan Schnell; All Rights Reserved
 # bitarray is published under the PSF license.
 #
 # Author: Ilan Schnell
@@ -61,9 +61,9 @@ Return a bitarray of `length` random bits (uses `os.urandom`).
 def pprint(__a, stream=None, group=8, indent=4, width=80):
     """pprint(bitarray, /, stream=None, group=8, indent=4, width=80)
 
-Prints the formatted representation of object on `stream`, followed by a
-newline.  If `stream` is `None`, `sys.stdout` is used.  By default, elements
-are grouped in bytes (8 elements), and 8 bytes (64 elements) per line.
+Prints the formatted representation of object on `stream` (which defaults
+to `sys.stdout`).  By default, elements are grouped in bytes (8 elements),
+and 8 bytes (64 elements) per line.
 Non-bitarray objects are printed by the standard library
 function `pprint.pprint()`.
 """
